Crate corevm_types

Crate corevm_types 

Types that are common across CoreVM guest, service, builder, monitor.

Modules

flags
Host-call flags.

Structs

AudioMode
Audio monitor output mode.
InputStreams
A set of input streams.
LenAndSourceOutcome
The base types for outcomes that encodes Option<(u32, u32)>, that contains length and source, as a single 64-bit value. None is encoded as u64::MAX, and thus length must be less than u32::MAX.
RecvHostMessageOutcome
The return type of recv_host_message host-call (message length and source).
RecvMessageOutcome
The return type of recv_message host-call (message length and source).
RecvTransactionOutcome
The return type of recv_transaction host-call (payload length and source).
VideoMode
Video monitor output mode.
VideoModeOptions
Optional video mode parameters.

Enums

AudioSampleFormat
The format of the samples emitted via yield_audio_samples.
InputVideoFrameFormat
The format of the input video frames accesed via read_video_frame.
VideoFrameFormat
The format of the frames emitted via [yield_video_frame].

Type Aliases

GuestId
CoreVM guest identifier.